from util import Enumerator
class TECErrors(Enumerator):
    kTextUnsupportedEncodingErr     = -8738             
    kTextMalformedInputErr          = -8739             
    kTextUndefinedElementErr        = -8740             
    kTECMissingTableErr             = -8745             
    kTECTableChecksumErr            = -8746             
    kTECTableFormatErr              = -8747             
    kTECCorruptConverterErr         = -8748             
    kTECNoConversionPathErr         = -8749             
    kTECBufferBelowMinimumSizeErr   = -8750             
    kTECArrayFullErr                = -8751             
    kTECBadTextRunErr               = -8752             
    kTECPartialCharErr              = -8753             
    kTECUnmappableElementErr        = -8754             
    kTECIncompleteElementErr        = -8755             
    kTECDirectionErr                = -8756             
    kTECGlobalsUnavailableErr       = -8770             
    kTECItemUnavailableErr          = -8771             
    kTECUsedFallbacksStatus         = -8783             
    kTECNeedFlushStatus             = -8784             
    kTECOutputBufferFullStatus      = -8785             

class UnicodeControlFlagBits(Enumerator):
    kUnicodeUseFallbacksBit       = 0
    kUnicodeKeepInfoBit           = 1
    kUnicodeDirectionalityBits    = 2
    kUnicodeVerticalFormBit       = 4
    kUnicodeLooseMappingsBit      = 5
    kUnicodeStringUnterminatedBit = 6
    kUnicodeTextRunBit            = 7
    kUnicodeKeepSameEncodingBit   = 8
    kUnicodeForceASCIIRangeBit    = 9
    kUnicodeNoHalfwidthCharsBit   = 10
    kUnicodeTextRunHeuristicsBit  = 11
    kUnicodeMapLineFeedToReturnBit = 12

class UnicodeControlFlags(Enumerator):
    kUnicodeUseFallbacksMask      = 1L << UnicodeControlFlagBits.kUnicodeUseFallbacksBit
    kUnicodeKeepInfoMask          = 1L << UnicodeControlFlagBits.kUnicodeKeepInfoBit
    kUnicodeDirectionalityMask    = 3L << UnicodeControlFlagBits.kUnicodeDirectionalityBits
    kUnicodeVerticalFormMask      = 1L << UnicodeControlFlagBits.kUnicodeVerticalFormBit
    kUnicodeLooseMappingsMask     = 1L << UnicodeControlFlagBits.kUnicodeLooseMappingsBit
    kUnicodeStringUnterminatedMask = 1L << UnicodeControlFlagBits.kUnicodeStringUnterminatedBit
    kUnicodeTextRunMask           = 1L << UnicodeControlFlagBits.kUnicodeTextRunBit
    kUnicodeKeepSameEncodingMask  = 1L << UnicodeControlFlagBits.kUnicodeKeepSameEncodingBit
    kUnicodeForceASCIIRangeMask   = 1L << UnicodeControlFlagBits.kUnicodeForceASCIIRangeBit
    kUnicodeNoHalfwidthCharsMask  = 1L << UnicodeControlFlagBits.kUnicodeNoHalfwidthCharsBit
    kUnicodeTextRunHeuristicsMask = 1L << UnicodeControlFlagBits.kUnicodeTextRunHeuristicsBit
    kUnicodeMapLineFeedToReturnMask = 1L << UnicodeControlFlagBits.kUnicodeMapLineFeedToReturnBit

class ScriptCode(Enumerator):
    smSystemScript                = -1    #  designates system script.
    smCurrentScript               = -2    #  designates current font script.
    smAllScripts                  = -3    #  designates any script
    smRoman                       = 0     
    smJapanese                    = 1 
    smTradChinese                 = 2     #  Traditional Chinese
    smKorean                      = 3     
    smArabic                      = 4 
    smHebrew                      = 5 
    smGreek                       = 6 
    smCyrillic                    = 7 
    smRSymbol                     = 8     #  Right-left symbol
    smDevanagari                  = 9 
    smGurmukhi                    = 10    
    smGujarati                    = 11 
    smOriya                       = 12 
    smBengali                     = 13    
    smTamil                       = 14    
    smTelugu                      = 15    
    smKannada                     = 16    #  Kannada/Kanarese
    smMalayalam                   = 17 
    smSinhalese                   = 18    
    smBurmese                     = 19    
    smKhmer                       = 20    #  Khmer/Cambodian
    smThai                        = 21    
    smLao                         = 22    
    smGeorgian                    = 23 
    smArmenian                    = 24    
    smSimpChinese                 = 25    #  Simplified Chinese
    smTibetan                     = 26    
    smMongolian                   = 27    
    smEthiopic                    = 28 
    smGeez                        = 28    #  Synonym for smEthiopic
    smCentralEuroRoman            = 29    #  For Czech, Slovak, Polish, Hungarian, Baltic langs
    smVietnamese                  = 30 
    smExtArabic                   = 31    #  extended Arabic
    smUninterp                    = 32    #  uninterpreted symbols, e.g. palette symbols
#  Extended script code for full Unicode input
    smUnicodeScript               = 0x7E

class LanguageCode(Enumerator):
    langEnglish                   = 0     #  smRoman script
    langFrench                    = 1     #  smRoman script
    langGerman                    = 2     #  smRoman script
    langItalian                   = 3     #  smRoman script
    langDutch                     = 4     #  smRoman script
    langSwedish                   = 5     #  smRoman script
    langSpanish                   = 6     #  smRoman script
    langDanish                    = 7     #  smRoman script
    langPortuguese                = 8     #  smRoman script
    langNorwegian                 = 9     #  smRoman script
    langHebrew                    = 10    #  smHebrew script
    langJapanese                  = 11    #  smJapanese script
    langArabic                    = 12    #  smArabic script
    langFinnish                   = 13    #  smRoman script
    langGreek                     = 14    #  Greek script using smRoman script code
    langIcelandic                 = 15    #  modified smRoman/Icelandic script
    langMaltese                   = 16    #  Roman script
    langTurkish                   = 17    #  modified smRoman/Turkish script
    langCroatian                  = 18    #  modified smRoman/Croatian script
    langTradChinese               = 19    #  Chinese (Mandarin) in traditional characters
    langUrdu                      = 20    #  smArabic script
    langHindi                     = 21    #  smDevanagari script
    langThai                      = 22    #  smThai script
    langKorean                    = 23    #  smKorean script

    langLithuanian                = 24    #  smCentralEuroRoman script
    langPolish                    = 25    #  smCentralEuroRoman script
    langHungarian                 = 26    #  smCentralEuroRoman script
    langEstonian                  = 27    #  smCentralEuroRoman script
    langLatvian                   = 28    #  smCentralEuroRoman script
    langSami                      = 29    #  language of the Sami people of N. Scandinavia             
    langFaroese                   = 30    #  modified smRoman/Icelandic script                      
    langFarsi                     = 31    #  modified smArabic/Farsi script
    langPersian                   = 31    #  Synonym for langFarsi
    langRussian                   = 32    #  smCyrillic script
    langSimpChinese               = 33    #  Chinese (Mandarin) in simplified characters
    langFlemish                   = 34    #  smRoman script
    langIrishGaelic               = 35    #  smRoman or modified smRoman/Celtic script (without dot above)   
    langAlbanian                  = 36    #  smRoman script
    langRomanian                  = 37    #  modified smRoman/Romanian script
    langCzech                     = 38    #  smCentralEuroRoman script
    langSlovak                    = 39    #  smCentralEuroRoman script
    langSlovenian                 = 40    #  modified smRoman/Croatian script
    langYiddish                   = 41    #  smHebrew script
    langSerbian                   = 42    #  smCyrillic script
    langMacedonian                = 43    #  smCyrillic script
    langBulgarian                 = 44    #  smCyrillic script
    langUkrainian                 = 45    #  modified smCyrillic/Ukrainian script
    langByelorussian              = 46    #  smCyrillic script
    langBelorussian               = 46    #  Synonym for langByelorussian                          
    langUzbek                     = 47    #  Cyrillic script
    langKazakh                    = 48    #  Cyrillic script
    langAzerbaijani               = 49    #  Azerbaijani in Cyrillic script
    langAzerbaijanAr              = 50    #  Azerbaijani in Arabic script
    langArmenian                  = 51    #  smArmenian script
    langGeorgian                  = 52    #  smGeorgian script
    langMoldavian                 = 53    #  smCyrillic script
    langKirghiz                   = 54    #  Cyrillic script
    langTajiki                    = 55    #  Cyrillic script
    langTurkmen                   = 56    #  Cyrillic script
    langMongolian                 = 57    #  Mongolian in smMongolian script
    langMongolianCyr              = 58    #  Mongolian in Cyrillic script
    langPashto                    = 59    #  Arabic script
    langKurdish                   = 60    #  smArabic script
    langKashmiri                  = 61    #  Arabic script
    langSindhi                    = 62    #  Arabic script
    langTibetan                   = 63    #  smTibetan script
    langNepali                    = 64    #  smDevanagari script
    langSanskrit                  = 65    #  smDevanagari script
    langMarathi                   = 66    #  smDevanagari script
    langBengali                   = 67    #  smBengali script
    langAssamese                  = 68    #  smBengali script
    langGujarati                  = 69    #  smGujarati script
    langPunjabi                   = 70    #  smGurmukhi script
    langOriya                     = 71    #  smOriya script
    langMalayalam                 = 72    #  smMalayalam script
    langKannada                   = 73    #  smKannada script
    langTamil                     = 74    #  smTamil script
    langTelugu                    = 75    #  smTelugu script
    langSinhalese                 = 76    #  smSinhalese script
    langBurmese                   = 77    #  smBurmese script
    langKhmer                     = 78    #  smKhmer script
    langLao                       = 79    #  smLao script
    langVietnamese                = 80    #  smVietnamese script
    langIndonesian                = 81    #  smRoman script
    langTagalog                   = 82    #  Roman script
    langMalayRoman                = 83    #  Malay in smRoman script
    langMalayArabic               = 84    #  Malay in Arabic script
    langAmharic                   = 85    #  smEthiopic script
    langTigrinya                  = 86    #  smEthiopic script
    langOromo                     = 87    #  smEthiopic script
    langSomali                    = 88    #  smRoman script
    langSwahili                   = 89    #  smRoman script
    langKinyarwanda               = 90    #  smRoman script
    langRuanda                    = 90    #  synonym for langKinyarwanda
    langRundi                     = 91    #  smRoman script
    langNyanja                    = 92    #  smRoman script
    langChewa                     = 92    #  synonym for langNyanja
    langMalagasy                  = 93    #  smRoman script
    langEsperanto                 = 94    #  Roman script
    langWelsh                     = 128   #  modified smRoman/Celtic script
    langBasque                    = 129   #  smRoman script
    langCatalan                   = 130   #  smRoman script
    langLatin                     = 131   #  smRoman script
    langQuechua                   = 132   #  smRoman script
    langGuarani                   = 133   #  smRoman script
    langAymara                    = 134   #  smRoman script
    langTatar                     = 135   #  Cyrillic script
    langUighur                    = 136   #  Arabic script
    langDzongkha                  = 137   #  (lang of Bhutan) smTibetan script
    langJavaneseRom               = 138   #  Javanese in smRoman script
    langSundaneseRom              = 139   #  Sundanese in smRoman script
    langGalician                  = 140   #  smRoman script
    langAfrikaans                 = 141   #  smRoman script                                   
    langBreton                    = 142   #  smRoman or modified smRoman/Celtic script                 
    langInuktitut                 = 143   #  Inuit script using smEthiopic script code                 
    langScottishGaelic            = 144   #  smRoman or modified smRoman/Celtic script                 
    langManxGaelic                = 145   #  smRoman or modified smRoman/Celtic script                 
    langIrishGaelicScript         = 146   #  modified smRoman/Gaelic script (using dot above)               
    langTongan                    = 147   #  smRoman script                                   
    langGreekPoly                 = 148   #  smGreek script                                   
    langGreenlandic               = 149   #  smRoman script                                   
    langAzerbaijanRoman           = 150   #  Azerbaijani in Roman script                             
    langUnspecified               = 32767 #  Special code for use in resources (such as 'itlm')           

class RegionCode(Enumerator):
  #  P/N    ISO    codes  comments
    verUS                         = 0     #        en_US
    verFrance                     = 1     #  F  fr_FR
    verBritain                    = 2     #  B  en_GB
    verGermany                    = 3     #  D  de_DE
    verItaly                      = 4     #  T  it_IT
    verNetherlands                = 5     #  N  nl_NL
    verFlemish                    = 6     #  FN nl_BE     Flemish (Dutch) for Belgium                 
    verSweden                     = 7     #  S  sv_SE
    verSpain                      = 8     #  E  es_ES       Spanish for Spain
    verDenmark                    = 9     #  DK da_DK
    verPortugal                   = 10    #  PO pt_PT     Portuguese for Portugal
    verFrCanada                   = 11    #  C  fr_CA       French for Canada
    verNorway                     = 12    #  H  no_NO,nb_NO  Bokm?l
    verIsrael                     = 13    #  HB he_IL,iw_IL Hebrew
    verJapan                      = 14    #  J  ja_JP
    verAustralia                  = 15    #  X  en_AU       English for Australia
    verArabic                     = 16    #  AB ar       Arabic for N Africa, Arabian peninsula, Levant
    verFinland                    = 17    #  K  fi_FI
    verFrSwiss                    = 18    #  SF fr_CH     French Swiss
    verGrSwiss                    = 19    #  SD de_CH     German Swiss
    verGreece                     = 20    #  GR el_GR     Monotonic Greek (modern)
    verIceland                    = 21    #  IS is_IS
    verMalta                      = 22    #  MA mt_MT
    verCyprus                     = 23    #  CY   _CY     Greek or Turkish language? Checking...
    verTurkey                     = 24    #  TU tr_TR
    verYugoCroatian               = 25    #  YU          Croatian for Yugoslavia; now use verCroatia (68)    
    verIndiaHindi                 = 33    #        hi_IN     Hindi for India
    verPakistanUrdu               = 34    #  UR ur_PK     Urdu for Pakistan                        
    verTurkishModified            = 35 
    verItalianSwiss               = 36    #  ST it_CH     Italian Swiss
    verInternational              = 37    #  Z  en      English for international use               
                                        #               38 is unassigned
    verRomania                    = 39    #  RO ro_RO
    verGreecePoly                 = 40    #        grc      Polytonic Greek (classical)                  
    verLithuania                  = 41    #  LT lt_LT
    verPoland                     = 42    #  PL pl_PL
    verHungary                    = 43    #  MG hu_HU
    verEstonia                    = 44    #  EE et_EE
    verLatvia                     = 45    #  LV lv_LV
    verSami                       = 46    #        se                                        
    verFaroeIsl                   = 47    #  FA fo_FO                                    
    verIran                       = 48    #  PS fa_IR     Persian/Farsi
    verRussia                     = 49    #  RS ru_RU     Russian
    verIreland                    = 50    #  GA ga_IE     Irish Gaelic for Ireland (without dot above)     
    verKorea                      = 51    #  KH ko_KR
    verChina                      = 52    #  CH zh_CN     Simplified Chinese
    verTaiwan                     = 53    #  TA zh_TW     Traditional Chinese
    verThailand                   = 54    #  TH th_TH
    verScriptGeneric              = 55    #  SS          Generic script system (no language or script)       
    verCzech                      = 56    #  CZ cs_CZ
    verSlovak                     = 57    #  SL sk_SK
    verFarEastGeneric             = 58    #  FE          Generic Far East system (no language or script)   
    verMagyar                     = 59    #               Unused; see verHungary
    verBengali                    = 60    #        bn         Bangladesh or India
    verByeloRussian               = 61    #  BY be_BY
    verUkraine                    = 62    #  UA uk_UA
                                        #               63 is unassigned
    verGreeceAlt                  = 64    #               unused                              
    verSerbian                    = 65    #  SR sr_YU,sh_YU                                   
    verSlovenian                  = 66    #  SV sl_SI                                    
    verMacedonian                 = 67    #  MD mk_MK                                    
    verCroatia                    = 68    #  CR hr_HR,sh_HR
                                        #               69 is unassigned
    verGermanReformed             = 70    #        de_DE     Reformed orthography (used formerly unassigned 70) 
    verBrazil                     = 71    #  BR pt_BR     Portuguese for Brazil
    verBulgaria                   = 72    #  BG bg_BG
    verCatalonia                  = 73    #  CA ca_ES     Catalan for Spain
    verMultilingual               = 74    #  ZM mul        (no language or script)
    verScottishGaelic             = 75    #  GD gd
    verManxGaelic                 = 76    #  GV gv       Isle of Man
    verBreton                     = 77    #  BZ br
    verNunavut                    = 78    #  IU iu_CA     Inuktitut for Canada
    verWelsh                      = 79    #  CU cy
                                        #               80 is ID for KCHR resource - Canadian CSA
    verIrishGaelicScript          = 81    #  GS ga_IE     Irish Gaelic for Ireland (using dot above)
    verEngCanada                  = 82    #  V  en_CA       English for Canada
    verBhutan                     = 83    #  BH dz_BT     Dzongkha for Bhutan
    verArmenian                   = 84    #  HY hy_AM
    verGeorgian                   = 85    #  KR ka_GE
    verSpLatinAmerica             = 86    #  LA es       Spanish for Latin America
                                        #               87 is ID for KCHR resource - Spanish ISO
    verTonga                      = 88    #  TS to_TO
                                        #               89 is ID for KCHR resource - Polish Modified
                                        #               90 is ID for KCHR resource - Catalan ISO
    verFrenchUniversal            = 91    #        fr         French generic
    verAustria                    = 92    #  AU de_AT     German for Austria
                                        #  Y          93 is unused alternate for verSpLatinAmerica
    verGujarati                   = 94    #        gu_IN
    verPunjabi                    = 95    #        pa         Pakistan or India
    verIndiaUrdu                  = 96    #        ur_IN     Urdu for India
    verVietnam                    = 97    #        vi_VN

    verFrBelgium                  = 98    #  BF fr_BE     French for Belgium                       
    verUzbek                      = 99    #  BD uz_UZ                                    
    verSingapore                  = 100   #  SG                                         
    verNynorsk                    = 101   #  NY nn_NO     Norwegian Nynorsk                        
    verAfrikaans                  = 102   #  AK af_ZA                                    
    verEsperanto                  = 103   #        eo                                        
    verMarathi                    = 104   #        mr_IN                                      
    verTibetan                    = 105   #        bo                                        
    verNepal                      = 106   #        ne_NP                                      
    verGreenland                  = 107   #        kl                                        
    verIrelandEnglish             = 108   #        en_IE     English for Ireland, with Euro for currency



_globals = globals()
for _v in _globals.values():    
    if isinstance(_v, type) and issubclass(_v, Enumerator):
        _globals.update(_v.__keys__)
del _globals, _v
